"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.EligibilityLightIcon = exports.iconPropTypes = void 0;
var lodash_1 = __importDefault(require("lodash"));
var react_1 = __importDefault(require("react"));
var prop_types_1 = __importDefault(require("prop-types"));
var Icon_1 = __importDefault(require("../Icon"));
var style_helpers_1 = require("../../../util/style-helpers");
var cx = style_helpers_1.lucidClassNames.bind('&-EligibilityLightIcon');
exports.iconPropTypes = {
    /** Valid eligibility options for the Icon. */
    eligibility: prop_types_1.default.oneOf(['left', 'right', 'neither', 'both']),
    /** Size variations of the icons. \`size\` directly effects height and width
        but the developer should also be conscious of the relationship with
        \`viewBox\`. */
    size: prop_types_1.default.number,
    /** Size handles width and height, whereas \`width\` can manually override the width that would be set by size. */
    width: prop_types_1.default.oneOfType([prop_types_1.default.number, prop_types_1.default.string]),
    /** Size handles width and height, whereas \`height\` can manually override the height that would be set by size. */
    height: prop_types_1.default.oneOfType([prop_types_1.default.number, prop_types_1.default.string]),
    /** \`viewBox\` is very important for SVGs. You can think of \`viewBox\` as
        the "artboard" for our SVG while \`size\` is the presented height and
        width. */
    viewBox: prop_types_1.default.string,
    /** Any valid SVG aspect ratio. */
    aspectRatio: prop_types_1.default.string,
    /** Adds styling that makes the icon appear clickable. */
    isClickable: prop_types_1.default.bool,
    /** Adds styling that makes the icon appear disabled.  Also forces
        isClickable to be false. */
    isDisabled: prop_types_1.default.bool,
    /** Called when the user clicks the \`Icon\`. Signature:
        \`({event, props}) => {}\` */
    onClick: prop_types_1.default.func,
    /** Called when the user clicks an active, clickable \`Icon\`. Signature:
        \`({event, props}) => {}\` */
    onSelect: prop_types_1.default.func,
    /** Any valid React children. */
    children: prop_types_1.default.element,
    /** Classes that are appended to the component defaults. This prop is run
        through the \`classnames\` library. */
    className: prop_types_1.default.string,
};
var EligibilityLightIcon = function (_a) {
    var className = _a.className, _b = _a.eligibility, eligibility = _b === void 0 ? 'neither' : _b, _c = _a.isDisabled, isDisabled = _c === void 0 ? false : _c, passThroughs = __rest(_a, ["className", "eligibility", "isDisabled"]);
    return (react_1.default.createElement(Icon_1.default
    // As color is fixed for this icon, editing the color prop is disallowed
    , __assign({}, lodash_1.default.omit(passThroughs, ['initialState']), { isDisabled: isDisabled, className: cx('&', className) }),
        react_1.default.createElement("g", null,
            react_1.default.createElement("path", { className: cx('&-half-circle', {
                    '&-is-selected': eligibility === 'left' || eligibility === 'both',
                    '&-half-circle-is-disabled': isDisabled,
                }), d: 'M6 14.71A7.003 7.003 0 0 1 6 1.29v13.42z' }),
            react_1.default.createElement("path", { className: cx('&-half-circle', {
                    '&-is-selected': eligibility === 'right' || eligibility === 'both',
                    '&-half-circle-is-disabled': isDisabled,
                }), d: 'M10 1.29a7.003 7.003 0 0 1 0 13.42V1.29z' }))));
};
exports.EligibilityLightIcon = EligibilityLightIcon;
exports.EligibilityLightIcon.displayName = 'EligibilityLightIcon';
exports.EligibilityLightIcon.propTypes = exports.iconPropTypes;
exports.EligibilityLightIcon.defaultProps = Icon_1.default.defaultProps;
exports.default = exports.EligibilityLightIcon;
//# sourceMappingURL=EligibilityLightIcon.js.map