import React from 'react';
import PropTypes from 'prop-types';
import { StandardProps } from '../../util/component-types';
export interface IAxisLabelProps extends StandardProps {
    /** Height of the margin this label should fit into. */
    height: number;
    /** Width of the margin this label should fit into. */
    width: number;
    /** Strings should match an existing color class unless they start with a '#'
     * for specific colors. E.g.:
     *
        - \`COLOR_0\`
        - \`COLOR_GOOD\`
        - \`'#123abc'\`
    `*/
    color: string;
    /** Contents of the label, should only ever be a string since we use a
        \`text\` under the hood. */
    label: string;
    /** Determine orientation of the label. */
    orient: 'top' | 'bottom' | 'left' | 'right';
}
export declare const AxisLabel: {
    (props: IAxisLabelProps): React.ReactElement;
    defaultProps: {
        color: string;
    };
    displayName: string;
    peek: {
        description: string;
        categories: string[];
    };
    propTypes: {
        /**
            Passed through to the root element.
        */
        style: PropTypes.Requireable<object>;
        /**
            Appended to the component-specific class names set on the root element.
        */
        className: PropTypes.Requireable<string>;
        /**
            Height of the margin this label should fit into.
        */
        height: PropTypes.Validator<number>;
        /**
            Width of the margin this label should fit into.
        */
        width: PropTypes.Validator<number>;
        /**
            Strings should match an existing color class unless they start with a '#'
            for specific colors. E.g.:
    
            - \`COLOR_0\`
            - \`COLOR_GOOD\`
            - \`'#123abc'\`
        */
        color: PropTypes.Requireable<string>;
        /**
            Contents of the label, should only ever be a string since we use a
            \`text\` under the hood.
        */
        label: PropTypes.Requireable<string>;
        /**
            Determine orientation of the label.
        */
        orient: PropTypes.Requireable<string>;
    };
};
export default AxisLabel;
//# sourceMappingURL=AxisLabel.d.ts.map