import React from 'react';
import PropTypes from 'prop-types';
import { StandardProps } from '../../util/component-types';
export interface IBarProps extends StandardProps, React.SVGProps<SVGRectElement> {
    /** x coordinate. */
    x: number;
    /** y coordinate. */
    y: number;
    /** Height of the bar. */
    height: number | string;
    /** Width of the bar. */
    width: number | string;
    /** Determines if the bar has a white stroke around it. */
    hasStroke: boolean;
    /** Strings should match an existing color class unless they start with a '#'
        for specific colors. E.g.:

        - \`COLOR_0\`
        - \`COLOR_GOOD\`
        - \`'#123abc'\`
     */
    color: string;
}
export declare const Bar: {
    (props: IBarProps): React.ReactElement;
    defaultProps: {
        x: number;
        y: number;
        height: number;
        width: number;
        color: string;
        hasStroke: boolean;
    };
    displayName: string;
    peek: {
        description: string;
        categories: string[];
    };
    propTypes: {
        /**
            Passed through to the root element.
        */
        style: PropTypes.Requireable<object>;
        /**
            Appended to the component-specific class names set on the root element.
        */
        className: PropTypes.Requireable<string>;
        /**
            x coordinate.
        */
        x: PropTypes.Requireable<number>;
        /**
            y coordinate.
        */
        y: PropTypes.Requireable<number>;
        /**
            Height of the bar.
        */
        height: PropTypes.Requireable<string | number>;
        /**
            Width of the bar.
        */
        width: PropTypes.Requireable<string | number>;
        /**
            Determines if the bar has a white stroke around it.
        */
        hasStroke: PropTypes.Requireable<boolean>;
        /**
            Strings should match an existing color class unless they start with a '#'
            for specific colors. E.g.:
    
            - \`COLOR_0\`
            - \`COLOR_GOOD\`
            - \`'#123abc'\`
        */
        color: PropTypes.Requireable<string>;
    };
};
export default Bar;
//# sourceMappingURL=Bar.d.ts.map