import _ from 'lodash';
import React from 'react';
import PropTypes from 'prop-types';
import Icon from '../Icon';
import { lucidClassNames } from '../../../util/style-helpers';
const cx = lucidClassNames.bind('&-InheritedSettingsIcon');
export const iconPropTypes = {
    /** Size variations of the icons. \`size\` directly effects height and width
        but the developer should also be conscious of the relationship with
        \`viewBox\`. */
    size: PropTypes.number,
    /** Size handles width and height, whereas \`width\` can manually override the width that would be set by size. */
    width: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
    /** Size handles width and height, whereas \`height\` can manually override the height that would be set by size. */
    height: PropTypes.oneOfType([PropTypes.number, PropTypes.string]),
    /** \`viewBox\` is very important for SVGs. You can think of \`viewBox\` as
        the "artboard" for our SVG while \`size\` is the presented height and
        width. */
    viewBox: PropTypes.string,
    /** Sets the color of the Icon.  May not be applicable for icons that are tied
        to specific colors (e.g. DangerIcon). */
    color: PropTypes.oneOf([
        'neutral-dark',
        'neutral-light',
        'neutral-extra-light',
        'primary',
        'white',
        'success',
        'warning',
        'secondary-one',
        'secondary-two',
        'secondary-three',
        'secondary-five',
    ]),
    /** Any valid SVG aspect ratio. */
    aspectRatio: PropTypes.string,
    /** Adds styling that makes the icon appear clickable. */
    isClickable: PropTypes.bool,
    /** Adds styling that makes the icon appear disabled.  Also forces
        isClickable to be false. */
    isDisabled: PropTypes.bool,
    /** Called when the user clicks the \`Icon\`. Signature:
        \`({event, props}) => {}\` */
    onClick: PropTypes.func,
    /** Called when the user clicks an active, clickable \`Icon\`. Signature:
        \`({event, props}) => {}\` */
    onSelect: PropTypes.func,
    /** Any valid React children. */
    children: PropTypes.element,
    /** Classes that are appended to the component defaults. This prop is run
        through the \`classnames\` library. */
    className: PropTypes.string,
};
export const InheritedSettingsIcon = ({ className, ...passThroughs }) => {
    return (React.createElement(Icon, { ..._.omit(passThroughs, ['initialState']), className: cx('&', className) },
        React.createElement("circle", { cx: '8', cy: '3.25', r: '2.75' }),
        React.createElement("path", { d: 'M2.75 15.5C3.993 15.5 5 14.493 5 13.25S3.993 11 2.75 11 .5 12.007.5 13.25s1.007 2.25 2.25 2.25zM13.25 15.5c1.243 0 2.25-1.007 2.25-2.25S14.493 11 13.25 11 11 12.007 11 13.25s1.007 2.25 2.25 2.25zM2.75 10.75V8.5h10.5v2.25M8 8.25v-2' })));
};
InheritedSettingsIcon.displayName = 'InheritedSettingsIcon';
InheritedSettingsIcon.propTypes = iconPropTypes;
InheritedSettingsIcon.defaultProps = Icon.defaultProps;
export default InheritedSettingsIcon;
//# sourceMappingURL=InheritedSettingsIcon.js.map