import React from 'react';
import PropTypes from 'prop-types';
import { StandardProps } from '../../util/component-types';
export interface ILineProps extends StandardProps, React.SVGProps<SVGPathElement> {
    /** The path for the line. */
    d?: string;
    /** Strings should match an existing color class unless they start with a '#' for specific colors. E.g.:

        - \`COLOR_0\`
        - \`COLOR_GOOD\`
        - \`'#123abc'\` */
    color: string;
    /** Display a dotted line. */
    isDotted: boolean;
}
export declare const Line: {
    (props: ILineProps): React.ReactElement;
    defaultProps: {
        color: string;
        isDotted: boolean;
    };
    displayName: string;
    peek: {
        description: string;
        categories: string[];
    };
    propTypes: {
        /**
            Passed through to the root element.
        */
        style: PropTypes.Requireable<object>;
        /**
            Appended to the component-specific class names set on the root element.
        */
        className: PropTypes.Requireable<string>;
        /**
            The path for the line.
        */
        d: PropTypes.Requireable<string>;
        /**
            Strings should match an existing color class unless they start with a '#' for specific colors. E.g.:
    
            - \`COLOR_0\`
            - \`COLOR_GOOD\`
            - \`'#123abc'\`
        */
        color: PropTypes.Requireable<string>;
        /**
            Display a dotted line.
        */
        isDotted: PropTypes.Requireable<boolean>;
    };
};
export default Line;
//# sourceMappingURL=Line.d.ts.map