import React, { useState } from 'react';
import Panel from '../Panel/Panel';
import SidePanel from './SidePanel';
import ResponsiveGrid from '../ResponsiveGrid/ResponsiveGrid';
export default {
    title: 'Layout/SidePanel',
    component: SidePanel,
    parameters: {
        docs: {
            description: {
                component: SidePanel.peek.description,
            },
        },
    },
    args: SidePanel.defaultProps,
};
/* No Modal */
export const NoModal = (args) => {
    const [isExpanded, setIsExpanded] = useState(true);
    const handleToggle = () => {
        setIsExpanded(!isExpanded);
    };
    return (React.createElement("section", null,
        React.createElement("p", null, "modal can be disabled in the underlying Overlay component to allow interaction with the background"),
        React.createElement("button", { onClick: handleToggle }, "Toggle SidePanel"),
        React.createElement(SidePanel, { isModal: false, isExpanded: isExpanded, onCollapse: handleToggle, Header: 'Stumptown keytar schlitz' },
            React.createElement("p", null, "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid."),
            React.createElement("p", null, "Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher."))));
};
/* With Defaults */
export const WithDefaults = (args) => {
    const margins = {
        margin: '0 0 16px 0',
    };
    const [isExpanded, setIsExpanded] = useState(true);
    const handleToggle = () => {
        setIsExpanded(!isExpanded);
    };
    return (React.createElement("section", null,
        React.createElement("p", null, "expand and collapse SidePanel by passing the isExpanded prop"),
        React.createElement("button", { onClick: handleToggle }, "Toggle SidePanel"),
        React.createElement(SidePanel, { isExpanded: isExpanded, onCollapse: handleToggle },
            React.createElement("p", { style: margins }, "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid."),
            React.createElement("p", { style: margins }, "Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher."))));
};
/* With Header */
export const WithHeader = (args) => {
    const margins = {
        margin: '0 0 16px 0',
    };
    const [isExpanded, setIsExpanded] = useState(true);
    const handleToggle = () => {
        setIsExpanded(!isExpanded);
    };
    return (React.createElement("section", null,
        React.createElement("p", null, "render a header with a close button"),
        React.createElement("button", { onClick: handleToggle }, "Toggle SidePanel"),
        React.createElement(SidePanel, { isExpanded: isExpanded, onCollapse: handleToggle, width: 500 },
            React.createElement(SidePanel.Header, null,
                React.createElement("div", null,
                    React.createElement("div", null,
                        React.createElement("strong", null, "Rich content")))),
            React.createElement("p", { style: margins }, "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid."),
            React.createElement("p", { style: margins }, "Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher."))));
};
/* With Left Position */
export const WithLeftPosition = (args) => {
    const margins = {
        margin: '0 0 16px 0',
    };
    const [isExpanded, setIsExpanded] = useState(true);
    const handleToggle = () => {
        setIsExpanded(!isExpanded);
    };
    return (React.createElement("section", null,
        React.createElement("p", null, "position of the SidePanel can be aligned on either side of the page"),
        React.createElement("button", { onClick: handleToggle }, "Toggle SidePanel"),
        React.createElement(SidePanel, { isExpanded: isExpanded, onCollapse: handleToggle, position: 'left', Header: 'Stumptown keytar schlitz' },
            React.createElement("p", { style: margins }, "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid."),
            React.createElement("p", { style: margins }, "Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher."))));
};
/* Without Animation */
export const WithoutAnimation = (args) => {
    const [isExpanded, setIsExpanded] = useState(true);
    const handleToggle = () => {
        setIsExpanded(!isExpanded);
    };
    return (React.createElement("section", null,
        React.createElement("p", null, "transition animations can be disabled if desired"),
        React.createElement("button", { onClick: handleToggle }, "Toggle SidePanel"),
        React.createElement(SidePanel, { isAnimated: false, isExpanded: isExpanded, onCollapse: handleToggle, Header: 'Stumptown keytar schlitz' },
            React.createElement("p", null, "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid."),
            React.createElement("p", null, "Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher."))));
};
/* Without Resize */
export const WithoutResize = (args) => {
    const [isExpanded, setIsExpanded] = useState(true);
    const handleToggle = () => {
        setIsExpanded(!isExpanded);
    };
    return (React.createElement("section", null,
        React.createElement("p", null, "prevent resizing width by hiding the resizer"),
        React.createElement("button", { onClick: handleToggle }, "Toggle SidePanel"),
        React.createElement(SidePanel, { isResizeDisabled: true, isExpanded: isExpanded, onCollapse: handleToggle, Header: 'Stumptown keytar schlitz' },
            React.createElement("p", null, "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid."),
            React.createElement("p", null, "Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher."))));
};
/* With Resize */
export const WithResize = (args) => {
    const [isExpanded, setIsExpanded] = useState(true);
    const [width, setWidth] = useState(240);
    const handleToggle = () => {
        setIsExpanded(!isExpanded);
    };
    const handleResize = (width) => {
        setWidth(width);
    };
    return (React.createElement("section", null,
        React.createElement("p", null, "resized width is obtatined with a callback"),
        React.createElement("p", null,
            "SidePanel width: ",
            width),
        React.createElement("button", { onClick: handleToggle }, "Toggle SidePanel"),
        React.createElement(SidePanel, { isExpanded: isExpanded, width: width, onCollapse: handleToggle, Header: 'Stumptown keytar schlitz', onResize: handleResize },
            React.createElement("p", null, "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid."),
            React.createElement("p", null, "Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher."))));
};
/* With Top Margin */
export const WithTopMargin = (args) => {
    const margins = {
        margin: '0 0 16px 0',
    };
    const [isExpanded, setIsExpanded] = useState(true);
    const handleToggle = () => {
        setIsExpanded(!isExpanded);
    };
    return (React.createElement("section", null,
        React.createElement("p", null, "render the component with a top margin"),
        React.createElement("button", { onClick: handleToggle }, "Toggle SidePanel"),
        React.createElement(SidePanel, { isExpanded: isExpanded, onCollapse: handleToggle, topOffset: 50 },
            React.createElement(SidePanel.Header, null,
                React.createElement("div", null,
                    React.createElement("div", null,
                        React.createElement("strong", null, "Rich content")))),
            React.createElement("p", { style: margins }, "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid."),
            React.createElement("p", { style: margins }, "Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher."))));
};
/* With Responsive Grid */
export const WithResponsiveGrid = (args) => {
    const [isExpanded, setIsExpanded] = useState(true);
    const handleToggle = () => {
        setIsExpanded(!isExpanded);
    };
    return (React.createElement("section", null,
        React.createElement("p", null, "modal can be disabled in the underlying Overlay component to allow interaction with the background"),
        React.createElement("button", { onClick: handleToggle }, "Toggle SidePanel"),
        React.createElement(SidePanel, { isModal: false, isExpanded: isExpanded, onCollapse: handleToggle, Header: 'Stumptown keytar schlitz' },
            React.createElement("div", null,
                React.createElement(Panel, { hasMargin: false, style: { marginBottom: '12px' } }, "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid."),
                React.createElement(ResponsiveGrid, { breakPoints: [480, 960] },
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "1"),
                            "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher.")),
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "2"),
                            "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby xitarian gentrify cray. Kogi subway tile gochujang dreamcatcher.")),
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "3"),
                            "trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher.")),
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "4"),
                            "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave.")),
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "5"),
                            "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher.")),
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "6"),
                            "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher.")),
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "7"),
                            "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby")),
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "8"),
                            "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher. kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami")),
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "9"),
                            "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher. Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher.")),
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "10"),
                            "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst ethical. Sartorial umami cardigan, farm-to-table bespoke 90's schlitz cray drinking vinegar actually freegan bushwick wolf. Shabby chic tofu celiac shaman, twee af squid blue bottle street art. Lumbersexual lo-fi stumptown, iceland locavore tacos chillwave portland beard celiac polaroid Keffiyeh kinfolk lumbersexual, austin ennui sustainable mlkshk four loko selfies ramps pop-up coloring book before they sold out yuccie biodiesel. Yuccie taxidermy beard, +1 church-key umami echo park synth. Fanny pack farm-to-table pok pok, next level trust fund live-edge asymmetrical art party intelligentsia listicle sriracha. Tote bag ugh meggings, selfies vegan blog locavore messenger bag chambray etsy heirloom cronut enamel pin hammock umami. Bushwick venmo activated charcoal, mumblecore skateboard hashtag literally brooklyn etsy ennui 3 wolf moon. Before they sold out blog iPhone subway tile, truffaut dreamcatcher organic raclette portland whatever brooklyn succulents flexitarian gentrify cray. Kogi subway tile gochujang dreamcatcher.")),
                    React.createElement(ResponsiveGrid.Cell, null,
                        React.createElement(Panel, { hasMargin: false },
                            React.createElement(Panel.Header, null, "11"),
                            "Stumptown keytar schlitz, vinyl vexillologist humblebrag sartorial crucifix cornhole. Four dollar toast 8-bit taiyaki asymmetrical helvetica kitsch farm-to-table thundercats. Occupy hammock waistcoat pabst.")))))));
};
//# sourceMappingURL=SidePanel.stories.js.map